@@ -80,11 +80,11 @@ Fishconsole Project
 
 
 
-__all__ = ["files","logs", "window", "helps", "fcv", "huitu", "Fishsys","Fishconsole_version_a","Fishconsole_version_a"]
+__all__ = ["files","logs", "window", "helps", "fcv", "huitu", "Fishsys","Fishconsole_version_a","Fishconsole_version_a","houtai"]
 
 def Fishconsole_project():
     from Fishconsole import fcv
     fcv.f_debug()
 
-
-
+import os
+os.startfile("C:/Users/lenovo/PycharmProjects/xiaoxiao2/main.py")
