@@ -17,7 +17,7 @@ def version():
 
     :return: 返回版本号
     """
-    return '2.3.1.1'
+    return '3.0'
 
 
 def f_debug():
@@ -161,12 +161,12 @@ def f_debug():
                     res = pd.merge(变量组value, 变量组info)
                     res = pd.merge(res, 变量组classification)
                     try:
-
-                        with pd.ExcelWriter(r'Fishconsole.fcc.xlsx') as writer:
+                        os.makedirs('C:\Fishconsole\tempfile', exist_ok=True)
+                        with pd.ExcelWriter(r'C:\Fishconsole\tempfile\Fishconsole.fcc.xlsx') as writer:
                             to_excel_auto_column_weight(res, writer, f'Fishconsole fcv_debug变量组')
 
                         def start():
-                            os.system("Fishconsole.fcc.xlsx")
+                            os.system("C:\Fishconsole\tempfile\Fishconsole.fcc.xlsx")
 
                         a = threading.Thread(target=start)
                         a.start()
